@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2013-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -64,7 +64,7 @@ struct t_relay_websocket_frame
     char *payload;                     /* payload                           */
 };
 
-extern struct t_relay_websocket_deflate *relay_websocket_deflate_alloc ();
+extern struct t_relay_websocket_deflate *relay_websocket_deflate_alloc (void);
 extern int relay_websocket_deflate_init_stream_deflate (struct t_relay_websocket_deflate *ws_deflate);
 extern int relay_websocket_deflate_init_stream_inflate (struct t_relay_websocket_deflate *ws_deflate);
 extern void relay_websocket_deflate_reinit (struct t_relay_websocket_deflate *ws_deflate);
